@@ -1,5 +1,8 @@
 #!/usr/bin/perl -w
 
+use warnings;
+use strict;
+
 use Net::DBus;
 use Net::DBus::Reactor;
 
